@@ -8,18 +8,18 @@ import flask
 import cloudevents.http
 from .locate import FindFunc, ArgumentConversion
 
-app = flask.Flask("func")
 
 
 def WrapFunction(func: typing.Callable) -> typing.Callable:
     sig = inspect.signature(func)
-    args = [ArgumentConversion(p) for p in sig.parameters]
+    args = [ArgumentConversion(p) for p in sig.parameters.values()]
     need_cloudevent = reduce(lambda a, b: a or b, (p.need_event for p in args))
 
-    def handler(req: flask.Request) -> flask.Response:
+    def handler() -> flask.Response:
+        req = flask.request
         event = None
         if need_cloudevent:
-            event = cloudevents.http.from_http(request.headers, request.get_data())
+            event = cloudevents.http.from_http(req.headers, req.get_data())
         
         params = {arg.name: arg.convert(req, event) for arg in args}
 
@@ -39,13 +39,15 @@ def WrapFunction(func: typing.Callable) -> typing.Callable:
 
         return flask.Response(result, 200)
 
-    print(f"$$ Converting {inspect.signature(func)} to {inspect.signature(wrapper)}")
-    return wrapper
+    print(f"$$ Converting {inspect.signature(func)} to {inspect.signature(handler)}")
+    return handler
 
 
-if __name__ == "__main__":
+def main():
     func = FindFunc(".")
     http_func = WrapFunction(func)
     # TODO: add option for GET / handle multiple functions
+    app = flask.Flask(func.__name__)
     app.add_url_rule("/",view_func=http_func, methods=['POST'])
     app.run(port=os.environ.get("PORT", 8080))
+
